global directory /Users/macbook/Dropbox/partitions_poland/REPLICATION/

clear
clear matrix
set mem 500m
set more off

cd $directory


use replication_gminy_elections_empires.dta, clear

gen large_cities=.
replace large_cities=1 if population_all>100000 & population_all!=.
replace large_cities=0 if population_all<=100000

gen pop_dens=lpop-log(area_gminy)
**********************************************************************************************************************

local sample3 (Russia|Austria )
local sample4 (prussia_notwt|Russia)

local name3 Russia_Austria_nowoj
local name4 prussia_notwt_Russia

local basecont " altitude_GPS  latitude longitude  large_cities "
local basecont3 " altitude_GPS  latitude longitude  large_cities "
local basecont4 " altitude_GPS  latitude longitude  large_cities "

local empires3 "Austria   "
local empires4 "Prussia   "

local econ_outcomes rail_within_15km lunem lumin_1995  less_than_secondary share_attending_mass share_attending_mass_reg_cath
local additional_econ_outcomes secondary_at road foreign_firms2009 revenues_capita
local political_outcomes PO PiS SLD turnout PSL 
local basic_geography "  precipit_ann median_temp_ann altitude_GPS"
local more_econ "wages_prct_cnt"
local powiaty_outcomes wages_prct_cnt lind_prod_capita services_2010 finance_insurance_2010 

local elections "election2 election3 election4"

local dist3 dist_austria_russia
local dist4 dist_russia_prussia_notwt
 
local dell x2 y2 xy x3 y3 x2y xy2 

local ref "year==2005"

******* Delete Warsaw-capital, as it is different from any other gminy

drop if powiaty_code==1431|powiaty_code==1465


keep if border==0

gen x=longitude
gen y=latitude
gen x2=x*x
gen x3=x*x*x
gen y2=y*y
gen y3=y*y*y
gen xy=x*y
gen x2y=x2*y
gen xy2=x*y2
gen xRussia=x*Russia
gen yRussia=y*Russia

gen const=1
gen xcut1=4
gen ycut1=4

replace foreign_firms2009=. if year!=2005
save temp, replace


*****************************
*****************************
*****ANALYSIS****************
*****************************
*****************************


*use temp, clear

**** Table 1 - nonparametric
****************************************
***RD GEOGRAPHY (Controls) --- TABLE 1
********************************************
********************************************


local isample=3
while "`sample`isample''"!="" {

	rd latitude dist_russia_prussia_all [weight=lpop] , cl(powiaty_code)
	outreg2 using "geography_`name`isample''.xls", replace ctitle(`dep' to replace ) bracket aster(se) se symbol(***, **, *) 

foreach dep in  `basecont' `basic_geography' urban { 

capture drop distance
gen distance =`dist`isample''

	rd `dep' distance if `sample`isample''&year==2005  [weight=lpop] , bw(60) cl(powiaty_code)
	scalar BW=e(w100)
	scalar BW50=e(w50)
	scalar BW200=e(w200) 
	outreg2 using "geography_`name`isample''.xls", append ctitle(`dep' ) bracket aster(se) se symbol(***, **, *) addstat("bw", BW, "bw50", BW50, "bw200", BW200)
           
}


local isample=`isample'+1
}
*/



*****************************
*****************************
*****************************



****************************************
***RD PARAMETRIC TABLES FOR ECONOMIC AND CULTURAL OUTCOMES GMINY LEVEL 
********TABLE 2, 3, 4***********************
********************************************
********************************************


*use temp, clear


local isample=3
while "`sample`isample''"!="" {

*use temp, clear
rd lunemp dist_russia_prussia_all [weight=lpop]
	outreg2 using "econ_`name`isample''.xls", replace ctitle(`dep' to replace ) bracket aster(se) se symbol(***, **, *) 
	
foreach dep in `econ_outcomes' { 	
*use temp, clear
capture drop distance
gen distance =`dist`isample''

	reg `dep'   `empires`isample''  `polylin`isample'' `basecont'  [aweight=lpop]  if `sample`isample'' & (abs(`dist`isample'')<=60)&`ref', cl(powiaty_code)
	outreg2 using "econ_`name`isample''.xls", append ctitle(`dep' "RDlin") bracket aster(se) se symbol(***, **, *) 
	
	}


**** DELL

foreach dep in  `econ_outcomes' { 	
	capture drop distance
	gen distance =`dist`isample''

	reg `dep'   `empires`isample'' `dell' `basecont'  [aweight=lpop]  if `sample`isample'' & (abs(`dist`isample'')<=60)&`ref', cl(powiaty_code)
	outreg2 using "econ_`name`isample''.xls", append ctitle(`dep' "RDlin") bracket aster(se) se symbol(***, **, *) 

	}


	local isample=`isample'+1
}

*/



********************************************
******POLITICAL LEGACIES - TABLE 5
********************************************
********************************************


*use temp, clear


local isample=3
while "`sample`isample''"!="" {

	rd lunemp dist_russia_prussia_all [weight=lpop] , cl(powiaty_code)
	outreg2 using "param_elec_`name`isample''.xls", replace ctitle(`dep' to replace ) bracket aster(se) se symbol(***, **, *) 

foreach dep in `political_outcomes'  {

	capture drop distance
	gen distance =`dist`isample''

	reg `dep'  `empires`isample'' `basecont'  `elections' `polylin`isample''  [aweight=lpop]  if `sample`isample'' & (abs(`dist`isample'')<=60), cl(powiaty_code)
	outreg2 using "param_elec_`name`isample''.xls", append ctitle(`dep' "RDlin") bracket aster(se) se symbol(***, **, *) 
 

 }



 //DEll
 foreach dep in `political_outcomes'   {

capture drop distance
gen distance =`dist`isample''	
	xi: reg `dep' `empires`isample'' `basecont'  `elections' `dell'  [aweight=lpop] if `sample`isample'' & (abs(`dist`isample'')<=60), cl(powiaty_code)
	outreg2 using "param_elec_`name`isample''.xls", append ctitle(`dep' "RDlin") bracket aster(se) se symbol(***, **, *) 
	} 
 
 
local isample=`isample'+1
}

*/


********************************************
********************************************
***************************************
***RD PARAMETRIC POWIATY LEVEL -TABLE LEGACIES POWIATY LEVEL
********************************************
********************************************

collapse  x y const turnout altitude_GPS  latitude longitude year large_cities wages_prct_cnt lpop lind_prod_capita border_russia_prussia border_wt_prussianotwt border_russia_austria border_russia_prussia_notwt dist_russia_prussia_notwt Russia_dist_russia_prussianotwt  dist_russia_prussia_all dist_austria_russia Russia_dist_russia_Prussia Russia_dist_austria_russia  Austria Russia Prussia prussia_notwt border  urban `dell' [aweight=lpop] , by(powiaty_code)

save collapsed_pow_macro, replace

sort powiaty_code 
merge powiaty_code using services_powiaty
tab _merge


local isample=3
while "`sample`isample''"!="" {

reg wages_prct_cnt dist_russia_prussia_all 
	outreg2 using "powiaty_`name`isample''.xls", replace ctitle(`dep' to replace ) bracket aster(se) se symbol(***, **, *) 
	
foreach dep in `powiaty_outcomes' { 	
capture drop distance
gen distance =`dist`isample''

	reg `dep'   `empires`isample''  `polylin`isample'' `basecont'    if `sample`isample'' & (abs(`dist`isample'')<=60), cl(powiaty_code)
	outreg2 using "powiaty_`name`isample''.xls", append ctitle(`dep' "RDlin") bracket aster(se) se symbol(***, **, *) 
	
	}


**** DELL

foreach dep in  `powiaty_outcomes' { 	
	capture drop distance
	gen distance =`dist`isample''

	reg `dep'   `empires`isample'' `dell' `basecont'  if `sample`isample'' & (abs(`dist`isample'')<=60), cl(powiaty_code)
	outreg2 using "powiaty_`name`isample''.xls", append ctitle(`dep' "RDlin") bracket aster(se) se symbol(***, **, *) 

	}


	local isample=`isample'+1
}

*/
erase collapsed_pow_macro.dta

*********************************************
***INTERPRETATION OF POLITICAL EFFECTS: TABLE 6
*********************************************
*********************************************
*********************************************

use temp, clear

keep if year==2005|year==2007|year==2011

xi: reg turnout Austria Prussia WT `elections'   , cl(powiaty_code)
outreg2 using "interp.xls", replace ctitle(`dep') bracket aster(se) se symbol(***, **, *) auto(2)

foreach dep in PO PiS SLD turnout{

xi: reg `dep' going_to prefer_de rail_within_15km Prussia Austria WT election2 election3 election4 altitude_GPS  latitude longitude  large_cities  , cl(powiaty_code)
outreg2 using "interp.xls", append ctitle(`dep') bracket aster(se) se symbol(***, **, *) auto(2) 
xi: reg `dep' share_attending_mass  prefer_de rail_within_15km Prussia Austria WT election2 election3 election4 altitude_GPS  latitude longitude  large_cities  , cl(powiaty_code)
outreg2 using "interp.xls", append ctitle(`dep') bracket aster(se) se symbol(***, **, *) auto(2) 
xi: reg `dep' share_attending_mass_reg_cath prefer_de rail_within_15km Prussia Austria WT election2 election3 election4 altitude_GPS  latitude longitude  large_cities  , cl(powiaty_code)
outreg2 using "interp.xls", append ctitle(`dep') bracket aster(se) se symbol(***, **, *) auto(2) 

}



lowess PO prefer_de, scheme(s2mono) msymbol(circle_hollow)
graph save PO_prefer_de, replace
lowess PiS going_to, scheme(s2mono) msymbol(circle_hollow)
graph save PiS_going_to, replace
lowess PiS share_attending_mass, scheme(s2mono) msymbol(circle_hollow)
graph save PiS_share_attending_mass, replace
lowess SLD going_to if SLD<80, scheme(s2mono) msymbol(circle_hollow)
graph save SLD_going_to, replace
lowess PO rail_within_15km, scheme(s2mono) msymbol(circle_hollow)
graph save PO_rail_within_15km, replace

*/

keep if year==2005|year==2007|year==2011

*****************************************
*****************************************
*****************************************

**** Graphs AUSTRIA

local graph_list  share_attending_mass sh_att_mass_reg_cath rail_within_15km  PO PiS SLD PSL 
set more on

capture drop bins_austria 
gen bins_austria=int((dist_austria_russia+2)/2) if dist_austria_russia>0
replace bins_austria=int((dist_austria_russia-2)/2) if dist_austria_russia<0

local width 100
foreach dep in `graph_list' { 
capture drop sum_bins_* count_bins_* vot_bins_*
egen sum_bins_`dep'=sum(`dep') if (Russia|Austria), by( bins_austria) 
egen count_bins_`dep'=count(`dep') if (Russia|Austria), by( bins_austria) 
gen vot_bins_`dep'=sum_bins_`dep'/count_bins_`dep'

label var vot_bins_`dep' "mean by distance bins of 3km"

twoway (lowess `dep' dist_austria_russia if (dist_austria_russia)<`width'&(dist_austria_russia)>0&(Russia|Austria),bw(60) xline(0) title(`: variable label `dep'') xtitle("Russia-Austria") lcolor(black) lpattern(dash)) || ( lowess `dep' dist_austria_russia if (dist_austria_russia)>-`width'&(dist_austria_russia)<0&(Russia|Austria), bw(60) lpattern(solid)) || (scatter vot_bins_`dep' dist_austria_russia if abs(dist_austria_russia)<`width'&(Austria|Russia), msymbol(smcircle_hollow)) 

graph save graph_`dep'_austria, replace
graph export graph_`dep'_austria.pdf, replace
more

}

*/



*********************************************
*********************************************
*********************************************
*********************************************


set more on

*** Graphs Prussia 

capture drop bins_prussia
gen bins_prussia=int((dist_russia_prussia_notwt+2)/2) if dist_russia_prussia_notwt>0
replace bins_prussia=int((dist_russia_prussia_notwt-2)/2) if dist_russia_prussia_notwt<0

local width 100
foreach dep in  `graph_list'  {
capture drop sum_bins_* count_bins_* vot_bins_*
egen sum_bins_`dep'=sum(`dep') if (prussia_notwt|Russia), by( bins_prussia) 
egen count_bins_`dep'=count(`dep') if (prussia_notwt|Russia), by( bins_prussia) 
gen vot_bins_`dep'=sum_bins_`dep'/count_bins_`dep'

label var vot_bins_`dep' "mean by distance bins of 3km"

twoway (lowess `dep' dist_russia_prussia_notwt if (dist_russia_prussia_notwt)<`width'&(dist_russia_prussia_notwt)>0&(prussia_notwt|Russia),bw(80) xline(0) title(`: variable label `dep'') xtitle("Russia-Prussia")  lcolor(black) lpattern(dash) ) || ( lowess `dep' dist_russia_prussia_notwt if abs(dist_russia_prussia_notwt)<`width'&(dist_russia_prussia_notwt)<0&(prussia_notwt|Russia), bw(80) lpattern(solid)) || (scatter vot_bins_`dep' dist_russia_prussia_notwt if abs(dist_russia_prussia_notwt)<`width'&(prussia_notwt|Russia), msymbol(smcircle_hollow) ) 
graph save graph_`dep'_prussia_, replace
graph export graph_`dep'_prussia_.pdf, replace
more
}

erase temp.dta




